.. _methods:

Methods
#######

*Note: This part of the documentation is work in progress!*

In these sections, the methods adapted and applied by BASTA is detailed.

The origin, justification and impact of the methods are not described here, but in the related papers.
This simply acts as a description of how the methods are applied, to understand how BASTA is used.

The following topics are covered:

.. toctree::
    :maxdepth: 2

    methods_stats
    methods_general
    methods_freqs
    methods_surfind
    methods_intpol
